==> bce-java-sdk-0.10.75-sources.jar: com/baidubce/services/bcc/model/VolumeAttachmentModel.java <==
/*
 * Copyright (c) 2014 Baidu.com, Inc. All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.bcc.model;

/**
 * volume attach info model which describes where the volume will attach to.
 */
public class VolumeAttachmentModel {

    /**
     * The id of volume
     */
    private String volumeId;

    /**
     * The id of instance.
     */
    private String instanceId;

    /**
     * The mounting path where the volume attached to the instance.
     */
    private String device;

    public String getVolumeId() {
        return volumeId;
    }

    public void setVolumeId(String volumeId) {
        this.volumeId = volumeId;
    }

    public String getInstanceId() {
        return instanceId;
    }

    public void setInstanceId(String instanceId) {
        this.instanceId = instanceId;
    }

    public String getDevice() {
        return device;
    }

    public void setDevice(String device) {
        this.device = device;
    }

    @Override
    public String toString() {
        return "VolumeAttachmentModel{"
                + "volumeId='" + volumeId + '\''
                + ", instanceId='" + instanceId + '\''
                + ", device='" + device + '\''
                + '}';
    }
}

==> bce-java-sdk-0.10.181-sources.jar: com/baidubce/services/bcc/model/VolumeAttachmentModel.java <==
/*
 * Copyright (c) 2014-2020 Baidu.com, Inc. All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.bcc.model;

/**
 * volume attach info model which describes where the volume will attach to.
 */
public class VolumeAttachmentModel {

    /**
     * The id of volume
     */
    private String volumeId;

    /**
     * The id of instance.
     */
    private String instanceId;

    /**
     * The mounting path where the volume attached to the instance.
     */
    private String device;

    /**
     * The serial number of Volume.
     */
    private String serial;

    public String getVolumeId() {
        return volumeId;
    }

    public void setVolumeId(String volumeId) {
        this.volumeId = volumeId;
    }

    public String getInstanceId() {
        return instanceId;
    }

    public void setInstanceId(String instanceId) {
        this.instanceId = instanceId;
    }

    public String getDevice() {
        return device;
    }

    public void setDevice(String device) {
        this.device = device;
    }

    public String getSerial() {
        return serial;
    }

    public void setSerial(String serial) {
        this.serial = serial;
    }

    @Override
    public String toString() {
        return "VolumeAttachmentModel{" +
                "volumeId='" + volumeId + '\'' +
                ", instanceId='" + instanceId + '\'' +
                ", device='" + device + '\'' +
                ", serial='" + serial + '\'' +
                '}';
    }
}
